
/*
 * Copyright (C) 2004-2005 Maximilian Schwerin
 *
 * This file is part of oxine a free media player.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 * $Id: dvd_menu.h 1182 2006-09-22 07:53:33Z mschwerin $
 *
 */
#ifndef DVD_MENU_H
#define DVD_MENU_H
#ifdef __cplusplus
extern "C" {
#endif

#define DVD_MENU_TITLE_1 _("Menu toggle")
#define DVD_MENU_TITLE_2 _("Title Menu")
#define DVD_MENU_TITLE_3 _("Root Menu")
#define DVD_MENU_TITLE_4 _("Subtitle Menu")
#define DVD_MENU_TITLE_5 _("Audio Menu")
#define DVD_MENU_TITLE_6 _("Angle Menu")
#define DVD_MENU_TITLE_7 _("Part Menu")

void dvd_menu1_cb (void *cb_data);
void dvd_menu2_cb (void *cb_data);
void dvd_menu3_cb (void *cb_data);
void dvd_menu4_cb (void *cb_data);
void dvd_menu5_cb (void *cb_data);
void dvd_menu6_cb (void *cb_data);
void dvd_menu7_cb (void *cb_data);

#ifdef __cplusplus
}
#endif
#endif /* DVD_MENU_H */
